import React, { Component } from 'react';
import App from './App';
import reducers from './reducers/reducer';
import { createStore,combineReducers } from 'redux';
import { Provider } from 'react-redux';
import {NativeEventEmitter} from 'react-native';
import JitsiManager from './lib/JitsiManager';
import Logger from './lib/Logger';
import AudioMode from './AudioMode'



export default class CometChatCallingComponent extends Component{

  
    constructor(props){
        super(props);
        const rootReducer = combineReducers(reducers);
        this.storeObj = createStore(rootReducer);
        JitsiManager.setCallObject(this.props.RTCUser,this.props.RTCReceiver,this.props.RTCInitiator,this.props.isInitiator);
        JitsiManager.setRegion(this.props.REGION);
        JitsiManager.setAudioOnly(this.props.isAudioOnly);
    }
    
    componentDidMount() {
        this.eventListener = new NativeEventEmitter(AudioMode);
        this.eventListener.addListener('CallEvent',(type) =>{
            Logger.log("CallEvent received : ",type)

            if(type.type == "EndCall"){
                this.props.onEndCall();
            }

            if(type.type == "EndCallButtonPressed"){
                this.props.onCallEndButtonPressed();
            }
        });
    }

    render(){
        return(
            <Provider store={this.storeObj}>
                <App 
                    sessionid={this.props.sessionId}
                    enableDefaultLayout = {this.props.enableDefaultLayout}
                    hideAudioMuteButton = {this.props.hideAudioMuteButton}
                    hideEndCallButton = {this.props.hideEndCallButton}
                    hidePauseVideoButton = {this.props.hidePauseVideoButton}
                    hideVideoSwitchButton = {this.props.hideVideoSwitchButton}
                    hideAudioModeButton = {this.props.hideAudioModeButton}
                    isAudioOnly = {this.props.isAudioOnly}
                    isConference = {this.props.isConference}
                    uid = {this.props.uid}
                />
            </Provider>
        );
    
    }
}  
CometChatCallingComponent.endCallSession=()=>{
    JitsiManager.onHangUp()
}
CometChatCallingComponent.switchCameraSource=()=>{
    JitsiManager.onSwitchCamera()
}
CometChatCallingComponent.muteAudio=()=>{
    JitsiManager.onMuteAudio()
}
CometChatCallingComponent.unMuteAudio=()=>{
    JitsiManager.onUnmuteAudio()
}
CometChatCallingComponent.pauseVideo=()=>{
    JitsiManager.onMuteVideo();
}
CometChatCallingComponent.unPauseVideo=()=>{
    JitsiManager.onUnmuteVideo();
}
CometChatCallingComponent.setAudioModeToSpeaker=()=>{
    JitsiManager.setAudioModeSpeaker();
}
CometChatCallingComponent.setAudioModeToEarPiece=()=>{
    JitsiManager.setAudioModeEarpiece();
}