import React, {Component} from 'react';
import { View, TouchableOpacity, ScrollView , Text ,Image } from 'react-native';
import { connect } from 'react-redux';
import {RTCView} from 'react-native-webrtc';
import { Platform } from '../react';
import Logger from 'react-native-cometchat-calling-component/lib/Logger';
import JitsiManager from 'react-native-cometchat-calling-component/lib/JitsiManager';


const TAG = 'ThumbnailView';
class ThumbnailView extends Component{
    constructor(props){
        super(props);
    }

    render(){
        var showImageThumb = JitsiManager.isAudioOnly;
        Logger.log(TAG,"New Users = ",this.props.users)
        if(showImageThumb){
            this.props.updateDominantVideoId('localVideo');
        }

        return(
            <ScrollView contentContainerStyle={this.style.lt_container} scrollEnabled={true} showsVerticalScrollIndicator={true} style={ this.style.container }>
                <View style={this.style.lt_container}>
                {
                    this.props.localTracks.map((track,index) => { 
                        if(track.type == "video"){
                            return (
                                <TouchableOpacity key={index} onPress={()=>{this.props.updateDominantVideoId('localVideo')}}>
                                    <View style={{ width: 120,margin: 5}} >
                                        {showImageThumb? null : <RTCView
                                            key={index}
                                            objectFit = "cover"
                                            streamURL = { track.getOriginalStream().toURL() }
                                            style={{ height: 120, width: 120}}
                                            zOrder={1}
                                        /> }

                                        <View style={this.style.container_background}>
                                            <Text numberOfLines={1} ellipsizeMode='tail' style={this.style.name}>
                                                {'You'}
                                            </Text>
                                        </View>
                                    </View>
                                </TouchableOpacity>
                            )
                        }
                    })
                }
                {
                    this.props.users.map((user,index) => {
                        if(user.videoTrack != null){        
                            Logger.log("User id : ",user);
                            var username,avatar;

                            Logger.log("UserName : ",username);
                            return (
                                <TouchableOpacity key={index} onPress={()=>{this.props.updateDominantVideoId(user.id)}}>
                                    <View style={{ width: 120,margin: 5}} >

                                        {showImageThumb ? <Image
                                                  style={{ height: 120, width: 120}}
                                                  resizeMode={"cover"}
                                                  source={{uri: avatar}}
                                                /> 
                                          : 
                                          <RTCView
                                            key={index}
                                            objectFit = "cover"
                                            streamURL = {user.videoTrack.getOriginalStream().toURL()}
                                            zOrder={1}
                                            style={{ height: 120, width: 120}}
                                        />}
                                        

                                        <View style={this.style.container_background}>
                                            <Text numberOfLines={1} ellipsizeMode='tail' style={this.style.name}>
                                                {user.name}
                                            </Text>
                                        </View>
                                        
                                        {/* <View style={{height:1},{width:1},{backgroundColor:'#000'}}>
                                            <Image source={require('../icons/icon_video_unmute.png')}/>
                                        </View> */}
                                    </View>
                                    
                                </TouchableOpacity>
                            )
                        }
                    })
                }
                </View>
            </ScrollView>
        )
    }

    style = {
        lt_container : { display:'flex', flexDirection: 'column-reverse', alignItems: 'flex-end', bottom: 0 },
        container: Platform.OS === 'ios' ? { display: 'flex', flex: 1, zIndex: 1, alignSelf: 'flex-end' }  : { flex:1, zIndex:5},
        name: {
            color: "#fff",
            alignSelf:'center',
            justifyContent: 'center',
            zIndex:5,
        },
        container_background:{
            justifyContent: 'center', 
            alignItems: 'center', 
            flexWrap: 'wrap', 
            opacity:0.4,
            position: 'absolute',
            padding: 5,
            backgroundColor: '#2e2f30',
        },
    };
}

function mapStateToProps (state) {
    return {
        localurl: state.url.localUrl,
        localTracks: state.tracks.localTracks,
        remoteTracks: state.tracks.remoteTracks,
        dominantVideoId: state.tracks.dominantVideoId,
        users : state.tracks.users,
    }
}

function mapDispatchToProps(dispatch){
    return{
        updateDominantVideoId: (id) => dispatch(data.updateDominantVideoId(id))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(ThumbnailView)